@@ -42,7 +42,7 @@ DEBUG_REGISTER(UMLDragData)
 /**
  *  Constructor.
  */
-UMLDragData::UMLDragData(UMLObjectList& objects, QWidget* dragSource /* = 0 */)
+UMLDragData::UMLDragData(UMLObjectList& objects, QWidget* dragSource /* = nullptr */)
 {
     Q_UNUSED(dragSource);
     setUMLDataClip1(objects);
@@ -53,7 +53,7 @@ UMLDragData::UMLDragData(UMLObjectList& objects, QWidget* dragSource /* = 0 */)
  * from the ListView to be copied, Mime type =
  * "application/x-uml-clip2
  */
-UMLDragData::UMLDragData(UMLObjectList& objects, UMLViewList& diagrams, QWidget* dragSource /* = 0 */)
+UMLDragData::UMLDragData(UMLObjectList& objects, UMLViewList& diagrams, QWidget* dragSource /* = nullptr */)
 {
     Q_UNUSED(dragSource);
     setUMLDataClip2(objects, diagrams);
@@ -63,7 +63,7 @@ UMLDragData::UMLDragData(UMLObjectList& objects, UMLViewList& diagrams, QWidget*
  *  Constructor.
  */
 UMLDragData::UMLDragData(UMLListViewItemList& umlListViewItems,
-                         QWidget* dragSource /* = 0 */)
+                         QWidget* dragSource /* = nullptr */)
 {
     Q_UNUSED(dragSource);
     setUMLDataClip3(umlListViewItems);
@@ -78,7 +78,7 @@ UMLDragData::UMLDragData(UMLListViewItemList& umlListViewItems,
  */
 UMLDragData::UMLDragData(UMLObjectList& objects,
                          UMLWidgetList& widgets, AssociationWidgetList& associationDatas,
-                         QPixmap& pngImage, UMLScene* scene, QWidget* dragSource /* = 0 */)
+                         QPixmap& pngImage, UMLScene *scene, QWidget *dragSource /* = nullptr */)
 {
     Q_UNUSED(dragSource);
     setUMLDataClip4(objects, widgets, associationDatas, pngImage, scene);
@@ -90,7 +90,7 @@ UMLDragData::UMLDragData(UMLObjectList& objects,
  * "application/x-uml-clip5
  */
 UMLDragData::UMLDragData(UMLObjectList& objects, int,
-                         QWidget* dragSource /* = 0 */)
+                         QWidget* dragSource /* = nullptr */)
 {
     Q_UNUSED(dragSource);
     setUMLDataClip5(objects);
@@ -99,7 +99,7 @@ UMLDragData::UMLDragData(UMLObjectList& objects, int,
 /**
  *  Constructor.
  */
-UMLDragData::UMLDragData(QWidget* dragSource /* = 0 */)
+UMLDragData::UMLDragData(QWidget* dragSource /* = nullptr */)
 {
     Q_UNUSED(dragSource);
 }
@@ -123,7 +123,7 @@ void UMLDragData::setUMLDataClip1(UMLObjectList& objects)
     stream.writeStartElement(QStringLiteral("umlobjects"));
 
     UMLObjectListIt object_it(objects);
-    UMLObject* obj = 0;
+    UMLObject *obj = nullptr;
     while (object_it.hasNext()) {
         obj = object_it.next();
         obj->saveToXMI(stream);
@@ -146,7 +146,7 @@ void UMLDragData::setUMLDataClip2(UMLObjectList& objects, UMLViewList& diagrams)
     stream.writeStartElement(QStringLiteral("umlobjects"));
 
     UMLObjectListIt object_it(objects);
-    UMLObject* obj = 0;
+    UMLObject *obj = nullptr;
     while (object_it.hasNext()) {
         obj = object_it.next();
         obj->saveToXMI(stream);
@@ -155,7 +155,7 @@ void UMLDragData::setUMLDataClip2(UMLObjectList& objects, UMLViewList& diagrams)
     stream.writeEndElement();  // umlobjects
     stream.writeStartElement(QStringLiteral("umlviews"));
 
-    foreach(UMLView* view, diagrams) {
+    for(UMLView* view : diagrams) {
         view->umlScene()->saveToXMI(stream);
     }
 
@@ -175,7 +175,7 @@ void UMLDragData::setUMLDataClip3(UMLListViewItemList& umlListViewItems)
     stream.writeStartElement(QStringLiteral("xmiclip"));
     stream.writeStartElement(QStringLiteral("umllistviewitems"));
 
-    foreach(UMLListViewItem* item, umlListViewItems) {
+    for(UMLListViewItem* item : umlListViewItems) {
         item->saveToXMI(stream);
     }
 
@@ -202,21 +202,21 @@ void UMLDragData::setUMLDataClip4(UMLObjectList& objects,
     stream.writeAttribute(QStringLiteral("diagramid"), Uml::ID::toString(scene->ID()));
     stream.writeStartElement(QStringLiteral("umlobjects"));
 
-    foreach (UMLObject* obj, objects) {
+    for(UMLObject* obj : objects) {
         obj->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // umlobjects
     stream.writeStartElement(QStringLiteral("widgets"));
 
-    foreach (UMLWidget* widget, widgets) {
+    for(UMLWidget* widget : widgets) {
         widget->saveToXMI(stream);
     }
 
     stream.writeEndElement();  // widgets
     stream.writeStartElement(QStringLiteral("associations"));
 
-    foreach (AssociationWidget* association, associations) {
+    for(AssociationWidget* association : associations) {
         association->saveToXMI(stream);
     }
 
@@ -225,7 +225,7 @@ void UMLDragData::setUMLDataClip4(UMLObjectList& objects,
     setData(QStringLiteral("application/x-uml-clip4"), xmiClip.toUtf8());
 
     QImage img = pngImage.toImage();
-    int l_size = img.byteCount();
+    int l_size = img.sizeInBytes();
     QByteArray clipdata;
     clipdata.resize(l_size);
     QDataStream clipstream(&clipdata, QIODevice::WriteOnly);
@@ -245,7 +245,7 @@ void UMLDragData::setUMLDataClip5(UMLObjectList& objects)
     stream.writeStartElement(QStringLiteral("xmiclip"));
     stream.writeStartElement(QStringLiteral("umlobjects"));
 
-    foreach (UMLObject* obj, objects) {
+    for(UMLObject* obj : objects) {
         obj->saveToXMI(stream);
     }
 
@@ -331,7 +331,7 @@ bool UMLDragData::decodeClip2(const QMimeData* mimeData, UMLObjectList& objects,
 
     // Load UMLObjects
     QDomNode objectsNode = xmiClipNode.firstChild();
-    if (NoteWidget::s_pCurrentNote == 0) {
+    if (NoteWidget::s_pCurrentNote == nullptr) {
         if (!UMLDragData::decodeObjects(objectsNode, objects, true)) {
             return false;
         }
@@ -618,7 +618,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     // Make sure all object widgets are loaded before adding messages or
     // preconditions
     if (!fromSameDiagram) {
-        foreach (UMLWidget* widget, widgets) {
+        for(UMLWidget *widget : widgets) {
             if (widget->isObjectWidget()) {
                 executeCreateWidgetCommand(widget);
             }
@@ -626,7 +626,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     }
 
     // Now add all remaining widgets
-    foreach (UMLWidget* widget, widgets) {
+    for(UMLWidget *widget : widgets) {
         if (!fromSameDiagram && widget->isMessageWidget()) {
             MessageWidget* message = widget->asMessageWidget();
             message->resolveObjectWidget(log);
@@ -648,7 +648,7 @@ bool UMLDragData::decodeClip4(const QMimeData* mimeData, UMLObjectList& objects,
     QDomElement associationWidgetElement = associationWidgetNode.toElement();
     while (!associationWidgetElement.isNull()) {
         AssociationWidget* associationWidget = AssociationWidget::create(view->umlScene());
-        if (associationWidget->loadFromXMI(associationWidgetElement, widgets, 0))
+        if (associationWidget->loadFromXMI(associationWidgetElement, widgets, nullptr))
             associations.append(associationWidget);
         else {
             delete associationWidget;
@@ -740,14 +740,14 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
     if (element.isNull()) {
         return false;//return ok as it means there is no umlobjects
     }
-    UMLObject* pObject = 0;
+    UMLObject *pObject = nullptr;
     while (!element.isNull()) {
-        pObject = 0;
+        pObject = nullptr;
         QString type = element.tagName();
         Uml::ID::Type elmId = Uml::ID::fromString(Model_Utils::getXmiId(element));
         QString stereotype = element.attribute(QStringLiteral("stereotype"));
 
-        bool objectExists = (doc->findObjectById(elmId) != 0);
+        bool objectExists = (doc->findObjectById(elmId) != nullptr);
 
         // This happens when pasting clip4 (widgets): pasting widgets must
         // not duplicate the UMLObjects, unless they don't exists (other
@@ -786,7 +786,7 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
         );
 
         // Determine the parent package of the pasted object
-        UMLPackage* newParent = 0;
+        UMLPackage *newParent = nullptr;
         if (oldParentId != Uml::ID::None) {
             Uml::ID::Type newParentId = doc->changeLog()->findNewID(oldParentId);
 
@@ -799,7 +799,7 @@ bool UMLDragData::decodeObjects(QDomNode& objectsNode, UMLObjectList& objects, b
             newParent = doc->findObjectById(newParentId)->asUMLPackage();
         }
 
-        if (newParent == 0) {
+        if (newParent == nullptr) {
             // Package is not in this clip, determine the parent based
             // on the selected tree view item
             newParent = Model_Utils::treeViewGetPackageFromCurrent();
@@ -860,10 +860,10 @@ bool UMLDragData::decodeViews(QDomNode& umlviewsNode, UMLViewList& diagrams)
         QString type = diagramElement.attribute(QStringLiteral("type"), QStringLiteral("0"));
         Uml::DiagramType::Enum dt = Uml::DiagramType::fromInt(type.toInt());
         UMLListViewItem *parent = listView->findFolderForDiagram(dt);
-        if (parent == 0)
+        if (parent == nullptr)
             return false;
         UMLObject *po = parent->umlObject();
-        if (po == 0 || po->baseType() != UMLObject::ot_Folder) {
+        if (po == nullptr || po->baseType() != UMLObject::ot_Folder) {
             logError0("UMLDragData::decodeViews: Bad parent for view.");
             return false;
         }
